@@ -16,7 +16,7 @@ from functools import cached_property
 from typing import ClassVar, Dict, List, Tuple
 
 from autotransform.batcher.base import Batch
-from autotransform.change.base import Change, ChangeName, ChangeState
+from autotransform.change.base import Change, ChangeName, ChangeState, ReviewState, TestState
 from autotransform.config import get_repo_config_relative_path
 from autotransform.item.base import FACTORY as item_factory
 from autotransform.schema.builder import FACTORY as schema_builder_factory
@@ -80,18 +80,7 @@ class GithubChange(Change):
         return self._pull_request.branch.split("/")[1].replace("_", " ")
 
     def get_state(self) -> ChangeState:
-        """Gets the current state of the Change. Caches the state in _state to prevent
-        excessive use of Github API.
-
-        Returns:
-            ChangeState: The current state of the Change.
-        """
-
-        return self._state
-
-    @cached_property
-    def _state(self) -> ChangeState:
-        """The current state of the Change as a cached property.
+        """Gets the current state of the Change.
 
         Returns:
             ChangeState: The current state of the Change.
@@ -101,12 +90,64 @@ class GithubChange(Change):
             return ChangeState.MERGED
         if self._pull_request.is_closed():
             return ChangeState.CLOSED
+        return ChangeState.OPEN
+
+    def get_mergeable_state(self) -> str:
+        """Gets the mergeable state of the Change.
+
+        Returns:
+            ChangeState: The mergeable state of the Change.
+        """
+
+        return self._pull_request.get_mergeable_state()
+
+    def get_review_state(self) -> ReviewState:
+        """Gets the current review state of the Change.
+
+        Returns:
+            ReviewState: The current review state of the Change.
+        """
+
+        return self._review_state
+
+    @cached_property
+    def _review_state(self) -> ReviewState:
+        """The current review state of the Change as a cached property.
+
+        Returns:
+            ReviewState: The current review state of the Change.
+        """
+
         review_state = self._pull_request.get_review_state()
         if review_state == "APPROVED":
-            return ChangeState.APPROVED
+            return ReviewState.APPROVED
         if review_state == "CHANGES_REQUESTED":
-            return ChangeState.CHANGES_REQUESTED
-        return ChangeState.OPEN
+            return ReviewState.CHANGES_REQUESTED
+        return ReviewState.NEEDS_REVIEW
+
+    def get_test_state(self) -> TestState:
+        """Gets the current test state of the Change.
+
+        Returns:
+            TestState: The current test state of the Change.
+        """
+
+        return self._test_state
+
+    @cached_property
+    def _test_state(self) -> TestState:
+        """The current test state of the Change as a cached property.
+
+        Returns:
+            TestState: The current test state of the Change.
+        """
+
+        state = self._pull_request.get_test_state()
+        if state == "pending":
+            return TestState.PENDING
+        if state in ["success", "neutral"]:
+            return TestState.SUCCESS
+        return TestState.FAILURE
 
     def get_labels(self) -> List[str]:
         """Gets all labels for a Change.
@@ -153,7 +194,7 @@ class GithubChange(Change):
 
         return self._pull_request.get_updated_at()
 
-    def _abandon(self) -> bool:
+    def abandon(self) -> bool:
         """Close the Pull Request and delete the associated branch.
 
         Returns:
@@ -164,7 +205,7 @@ class GithubChange(Change):
             return False
         return self._pull_request.delete_branch()
 
-    def _add_labels(self, labels: List[str]) -> bool:
+    def add_labels(self, labels: List[str]) -> bool:
         """Adds labels to an outstanding Change.
 
         Args:
@@ -177,7 +218,7 @@ class GithubChange(Change):
         self._pull_request.add_labels(labels)
         return True
 
-    def _add_reviewers(self, reviewers: List[str], team_reviewers: List[str]) -> bool:
+    def add_reviewers(self, reviewers: List[str], team_reviewers: List[str]) -> bool:
         """Adds reviewers to an outstanding Change.
 
         Args:
@@ -191,7 +232,7 @@ class GithubChange(Change):
         self._pull_request.add_reviewers(reviewers, team_reviewers)
         return True
 
-    def _comment(self, body: str) -> bool:
+    def comment(self, body: str) -> bool:
         """Comments on an outstanding Change.
 
         Args:
@@ -204,7 +245,7 @@ class GithubChange(Change):
         self._pull_request.create_comment(body)
         return True
 
-    def _merge(self) -> bool:
+    def merge(self) -> bool:
         """Merges the Pull Request and deletes the branch.
 
         Returns:
@@ -215,7 +256,7 @@ class GithubChange(Change):
             return False
         return self._pull_request.delete_branch()
 
-    def _remove_label(self, label: str) -> bool:
+    def remove_label(self, label: str) -> bool:
         """Removes a label from an outstanding Change.
 
         Args:
@@ -228,12 +269,12 @@ class GithubChange(Change):
         self._pull_request.remove_label(label)
         return True
 
-    @cached_property
+    @property
     def _pull_request(self) -> PullRequest:
-        """Gets the Pull Request as a cached property.
+        """Gets the Pull Request.
 
         Returns:
-            PullRequest: The PullRequest.
+            PullRequest: The Pull Request.
         """
 
         return GithubUtils.get(self.full_github_name).get_pull_request(self.pull_number)
