@@ -7,7 +7,7 @@
 
 # @black_format
 
-"""The base class for SchemaBuilders which are used to programatically generate a Schema."""
+"""The base class and associated classes for SchemaBuilders."""
 
 import json
 from abc import abstractmethod
@@ -141,6 +141,6 @@ class SchemaBuilder(NamedComponent):
 
 FACTORY = ComponentFactory(
     {},
-    SchemaBuilder,  # type: ignore [misc]
+    SchemaBuilder,  # type: ignore [type-abstract]
     "schema_builder.json",
 )
