@@ -11,7 +11,7 @@
 
 from argparse import ArgumentParser, Namespace
 
-from autotransform.config.default import DefaultConfigFetcher
+from autotransform.config import get_repo_config_relative_path
 from autotransform.event.debug import DebugEvent
 from autotransform.event.handler import EventHandler
 from autotransform.event.logginglevel import LoggingLevel
@@ -42,7 +42,26 @@ def add_args(parser: ArgumentParser) -> None:
         required=False,
         help="Tells the script to output verbose logs.",
     )
-    parser.set_defaults(func=manage_command_main)
+
+    mode_group = parser.add_mutually_exclusive_group()
+    mode_group.add_argument(
+        "-l",
+        "--local",
+        dest="run_local",
+        action="store_true",
+        required=False,
+        help="Tells the script to use the local runner.",
+    )
+    mode_group.add_argument(
+        "-r",
+        "--remote",
+        dest="run_local",
+        action="store_false",
+        required=False,
+        help="Tells the script to use the remote runner. This is the default mode.",
+    )
+
+    parser.set_defaults(run_local=False, func=manage_command_main)
 
 
 def manage_command_main(args: Namespace) -> None:
@@ -58,14 +77,13 @@ def manage_command_main(args: Namespace) -> None:
     if args.verbose:
         event_handler.set_logging_level(LoggingLevel.DEBUG)
 
-    # Get Manager
     manager_file = args.path
     if manager_file is None:
-        manager_file = f"{DefaultConfigFetcher.get_repo_config_relative_path()}/manager.json"
+        manager_file = f"{get_repo_config_relative_path()}/manager.json"
     event_args = {"manager_file": manager_file}
     manager = Manager.read(manager_file)
     event_args["manager"] = manager
     event_handler.handle(ScriptRunEvent({"script": "manage", "args": event_args}))
 
-    event_handler.handle(DebugEvent({"message": f"Running manager: {manager}"}))
-    manager.run()
+    event_handler.handle(DebugEvent({"message": f"Running manager: {manager!r}"}))
+    manager.run(args.run_local)
